@@ -30,6 +30,11 @@ def execute_handler(handler: Handler):
         pass
 
     for model in kwargs.values():
+        if isinstance(model, UserProxyModel):
+            model.save()
+        elif isinstance(model, UserModel):
+            model.save(as_current=True)
+
         model.save()
 
     if handler.exclusive:
